=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-08-08 15:51:23 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-08-08 15:59:57 +0000
@@ -6889,7 +6889,7 @@
 
   ut_a(prebuilt->trx == session_to_trx(getTable()->in_use));
 
-  prebuilt->trx->op_info = (char*)"estimating records in index range";
+  prebuilt->trx->op_info = "estimating records in index range";
 
   /* In case MySQL calls this in the middle of a SELECT query, release
   possible adaptive hash latch to avoid deadlocks of threads */
@@ -6961,7 +6961,7 @@
 func_exit:
   free(key_val_buff2);
 
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   /* The MySQL optimizer seems to believe an estimate of 0 rows is
   always accurate and may return the result 'Empty set' based on that.
@@ -7022,7 +7022,7 @@
   estimate = 2 * local_data_file_length /
            dict_index_calc_min_rec_len(index);
 
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   return((ha_rows) estimate);
 }
@@ -7212,7 +7212,7 @@
   /* In case MySQL calls this in the middle of a SELECT query, release
   possible adaptive hash latch to avoid deadlocks of threads */
 
-  prebuilt->trx->op_info = (char*)"returning various info to MySQL";
+  prebuilt->trx->op_info = "returning various info to MySQL";
 
   trx_search_latch_release_if_reserved(prebuilt->trx);
 
@@ -7459,7 +7459,7 @@
   }
 
 func_exit:
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   return(0);
 }
@@ -7670,7 +7670,7 @@
 
   update_session(getTable()->in_use);
 
-  prebuilt->trx->op_info = (char*)"returning table comment";
+  prebuilt->trx->op_info = "returning table comment";
 
   /* In case MySQL calls this in the middle of a SELECT query, release
   possible adaptive hash latch to avoid deadlocks of threads */
@@ -7715,7 +7715,7 @@
 
   mutex_exit(&srv_dict_tmpfile_mutex);
 
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   return(str ? str : (char*) comment);
 }
@@ -7741,7 +7741,7 @@
 
   update_session(getTable()->in_use);
 
-  prebuilt->trx->op_info = (char*)"getting info on foreign keys";
+  prebuilt->trx->op_info = "getting info on foreign keys";
 
   /* In case MySQL calls this in the middle of a SELECT query,
   release possible adaptive hash latch to avoid
@@ -7755,7 +7755,7 @@
   /* output the data to a temporary file */
   dict_print_info_on_foreign_keys(TRUE, srv_dict_tmpfile,
         prebuilt->trx, prebuilt->table);
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   flen = ftell(srv_dict_tmpfile);
   if (flen < 0) {
@@ -7783,19 +7783,15 @@
 int
 ha_innobase::get_foreign_key_list(Session *session, List<ForeignKeyInfo> *f_key_list)
 {
-  dict_foreign_t* foreign;
-
   ut_a(prebuilt != NULL);
   update_session(getTable()->in_use);
-  prebuilt->trx->op_info = (char*)"getting list of foreign keys";
+  prebuilt->trx->op_info = "getting list of foreign keys";
   trx_search_latch_release_if_reserved(prebuilt->trx);
   mutex_enter(&(dict_sys->mutex));
-  foreign = UT_LIST_GET_FIRST(prebuilt->table->foreign_list);
+  dict_foreign_t* foreign = UT_LIST_GET_FIRST(prebuilt->table->foreign_list);
 
   while (foreign != NULL) {
 
-    uint i;
-    lex_string_t *name = 0;
     uint ulen;
     char uname[NAME_LEN + 1];           /* Unencoded name */
     char db_name[NAME_LEN + 1];
@@ -7803,7 +7799,7 @@
 
     /** Foreign id **/
     tmp_buff = foreign->id;
-    i = 0;
+    uint i = 0;
     while (tmp_buff[i] != '/')
       i++;
     tmp_buff += i + 1;
@@ -7832,12 +7828,8 @@
     List<lex_string_t> tmp_referenced_fields;
     for (i= 0;;) 
 		{
-      tmp_buff= foreign->foreign_col_names[i];
-      name = session->make_lex_string(NULL, str_ref(tmp_buff));
-      tmp_foreign_fields.push_back(name);
-      tmp_buff= foreign->referenced_col_names[i];
-      name = session->make_lex_string(NULL, str_ref(tmp_buff));
-      tmp_referenced_fields.push_back(name);
+      tmp_foreign_fields.push_back(session->make_lex_string(NULL, str_ref(foreign->foreign_col_names[i])));
+      tmp_referenced_fields.push_back(session->make_lex_string(NULL, str_ref(foreign->referenced_col_names[i])));
       if (++i >= foreign->n_fields)
         break;
     }
@@ -7890,8 +7882,7 @@
 
     lex_string_t *tmp_referenced_key_name = NULL;
 
-    if (foreign->referenced_index &&
-        foreign->referenced_index->name)
+    if (foreign->referenced_index && foreign->referenced_index->name)
     {
       tmp_referenced_key_name = session->make_lex_string(NULL, str_ref(foreign->referenced_index->name));
     }
@@ -7901,12 +7892,11 @@
                               tmp_update_method, tmp_delete_method, tmp_referenced_key_name,
                               tmp_foreign_fields, tmp_referenced_fields);
 
-    ForeignKeyInfo *pf_key_info = (ForeignKeyInfo*)session->mem.memdup(&f_key_info, sizeof(ForeignKeyInfo));
-    f_key_list->push_back(pf_key_info);
+    f_key_list->push_back((ForeignKeyInfo*)session->mem.memdup(&f_key_info, sizeof(ForeignKeyInfo)));
     foreign = UT_LIST_GET_NEXT(foreign_list, foreign);
   }
   mutex_exit(&(dict_sys->mutex));
-  prebuilt->trx->op_info = (char*)"";
+  prebuilt->trx->op_info = "";
 
   return(0);
 }

